summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/libgpgme-copy/gpgme/gpgme.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdenetwork/libgpgme-copy/gpgme/gpgme.h')
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/gpgme.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/libkdenetwork/libgpgme-copy/gpgme/gpgme.h b/libkdenetwork/libgpgme-copy/gpgme/gpgme.h
index 4615667f..577f9c33 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/gpgme.h
+++ b/libkdenetwork/libgpgme-copy/gpgme/gpgme.h
@@ -137,8 +137,8 @@ const char *gpgme_strerror (gpgme_error_t err);
size BUFLEN. This function is, in contrast to gpg_strerror,
thread-safe if a thread-safe strerror_r() function is provided by
the system. If the function succeeds, 0 is returned and BUF
- contains the string describing the error. If the buffer was not
- large enough, ERANGE is returned and BUF contains as much of the
+ tqcontains the string describing the error. If the buffer was not
+ large enough, ERANGE is returned and BUF tqcontains as much of the
beginning of the error string as fits into the buffer. */
int gpgme_strerror_r (gpg_error_t err, char *buf, size_t buflen);
@@ -326,7 +326,7 @@ struct _gpgme_sig_notation
{
struct _gpgme_sig_notation *next;
/* If NAME is a null pointer, then VALUE contains a policy URL
rather than a notation. */
char *name;
@@ -687,19 +687,19 @@ struct _gpgme_key
/* This is the protocol supported by this key. */
gpgme_protocol_t protocol;
/* If protocol is GPGME_PROTOCOL_CMS, this string contains the
issuer serial. */
char *issuer_serial;
/* If protocol is GPGME_PROTOCOL_CMS, this string contains the
issuer name. */
char *issuer_name;
/* If protocol is GPGME_PROTOCOL_CMS, this string contains the chain
ID. */
char *chain_id;
/* If protocol is GPGME_PROTOCOL_OpenPGP, this field contains the
owner trust. */
gpgme_validity_t owner_trust;
@@ -1694,7 +1694,7 @@ typedef gpgme_encrypt_result_t GpgmeEncryptResult _GPGME_DEPRECATED;
typedef gpgme_sig_notation_t GpgmeSigNotation _GPGME_DEPRECATED;
typedef gpgme_signature_t GpgmeSignature _GPGME_DEPRECATED;
typedef gpgme_verify_result_t GpgmeVerifyResult _GPGME_DEPRECATED;
-typedef gpgme_import_status_t GpgmeImportStatus _GPGME_DEPRECATED;
+typedef gpgme_import_status_t GpgmeImporStatus _GPGME_DEPRECATED;
typedef gpgme_import_result_t GpgmeImportResult _GPGME_DEPRECATED;
typedef gpgme_genkey_result_t GpgmeGenKeyResult _GPGME_DEPRECATED;
typedef gpgme_trust_item_t GpgmeTrustItem _GPGME_DEPRECATED;
@@ -326,7 +326,7 @@ struct _gpgme_sig_notation
{
struct _gpgme_sig_notation *next;
- /* If NAME is a null pointer, then VALUE contains a policy URL
+ /* If NAME is a null pointer, then VALUE tqcontains a policy URL
rather than a notation. */
char *name;
@@ -687,19 +687,19 @@ struct _gpgme_key
/* This is the protocol supported by this key. */
gpgme_protocol_t protocol;
- /* If protocol is GPGME_PROTOCOL_CMS, this string contains the
+ /* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the
issuer serial. */
char *issuer_serial;
@@ -687,19 +687,19 @@ struct _gpgme_key
issuer serial. */
char *issuer_serial;
- /* If protocol is GPGME_PROTOCOL_CMS, this string contains the
+ /* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the
issuer name. */
char *issuer_name;
@@ -687,19 +687,19 @@ struct _gpgme_key
issuer name. */
char *issuer_name;
- /* If protocol is GPGME_PROTOCOL_CMS, this string contains the chain
+ /* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the chain
ID. */
char *chain_id;
@@ -687,19 +687,19 @@ struct _gpgme_key
ID. */
char *chain_id;
- /* If protocol is GPGME_PROTOCOL_OpenPGP, this field contains the
+ /* If protocol is GPGME_PROTOCOL_OpenPGP, this field tqcontains the
owner trust. */
gpgme_validity_t owner_trust;